<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="53"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Grafični vmesnik za uporabo izbranih uporabnih spreprilagoditev</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>launches brightness-systray</source>
        <translation>zažene svetlobo v sistemski pasici</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>se odpre z odprtim zavihkom zaslona. Deluje le, če je zagnan Xfce namizje</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>Neposredno odpri zavihek teme. Deluje le na Xfce in Fluxbox namizjih</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Display additional debug output in console</source>
        <translation>V konzoli prikaži dodaten izpis za razhroščevanje</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Zavihek neposredno odpre. Deluje na vseh namizjih</translation>
    </message>
</context>
<context>
    <name>Tweak</name>
    <message>
        <location filename="../tweak.ui" line="14"/>
        <location filename="../tweak.cpp" line="71"/>
        <location filename="../tweak.cpp" line="242"/>
        <location filename="../tweak.cpp" line="261"/>
        <source>MX Tweak</source>
        <translation>MX prilagoditve</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="33"/>
        <source>Xfce Panel</source>
        <translation>Xfce pano</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="39"/>
        <location filename="../tweak.ui" line="233"/>
        <location filename="../tweak.ui" line="508"/>
        <location filename="../tweak.ui" line="587"/>
        <location filename="../tweak.ui" line="643"/>
        <location filename="../tweak.ui" line="670"/>
        <location filename="../tweak.ui" line="862"/>
        <location filename="../tweak.ui" line="1253"/>
        <location filename="../tweak.ui" line="1382"/>
        <location filename="../tweak.ui" line="1429"/>
        <location filename="../tweak.ui" line="1679"/>
        <source>Apply</source>
        <extracomment>apply changes</extracomment>
        <translation>Uveljavi</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="58"/>
        <source>Tasklist</source>
        <translation>Seznam opravil</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="64"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Nastavi vtiičnik seznama opravila na:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="71"/>
        <source>Docklike is the modern dock plugin for the panel. Window Buttons is the classic tasklist without dock features.</source>
        <translation>Docklike je moderen vtičnik za sidrišče na panoju. Windows Buttons je klasični seznam opravil brez funkciji sidrišča.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="78"/>
        <source>Tasklist Options</source>
        <translation>Možnosti seznama opravil</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="85"/>
        <source>Docklike Options</source>
        <translation>Docklike možnosti</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="95"/>
        <source>Affects 1st Panel</source>
        <translation>Vpliva na prvi pano</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="101"/>
        <location filename="../tweak.ui" line="1036"/>
        <location filename="../tweak.ui" line="1146"/>
        <location filename="../tweak.ui" line="1273"/>
        <source>Placement</source>
        <translation>Postavitev</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="114"/>
        <source>Backup/Restore Configuration (all panels)</source>
        <translation>Varnostno kopiraj/Obnovi konfiguracijo (vsi panoji)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="127"/>
        <source>Backup current panel configuration</source>
        <translation>Varnostno kopiraj trenutno konfiguracijo panojev</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="141"/>
        <source>Restore selected panel configuration</source>
        <translation>Obnovi izbrano konfiguracijo panoja</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="148"/>
        <source>Restore default panel</source>
        <translation>Obnovi privzete panoje</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="158"/>
        <source>Panel Plugin Scales</source>
        <translation>Povečava vtičnika panoja</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="164"/>
        <source>Volume</source>
        <extracomment>volume plugin scale factor</extracomment>
        <translation>Nosilec</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="184"/>
        <source>Power Manager</source>
        <extracomment>power manager plugin scale factor</extracomment>
        <translation>Upravljalnik rabe energije</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="221"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="227"/>
        <source>Theme Options</source>
        <translation>Opcije za temo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="262"/>
        <source>Remove User Theme Set</source>
        <translation>Odstranite uporabnikov tematski set</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="275"/>
        <source>Themes</source>
        <translation>Teme</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="281"/>
        <source>Application</source>
        <extracomment>theme an application will get</extracomment>
        <translation>Program</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="295"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Toggle Dark Mode for GTK4 libadwaita applications&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Preklopi temni način za GTK4 libadwaita programe &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="298"/>
        <source>Dark Mode</source>
        <translation>Temni način</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="305"/>
        <location filename="../tweak.ui" line="1742"/>
        <source>Window Manager</source>
        <extracomment>theme a window manager border will get</extracomment>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="319"/>
        <source>Legacy Styles</source>
        <translation>Starejši slogi</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="332"/>
        <source>Icons</source>
        <extracomment>icon theme</extracomment>
        <translation>Ikone</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="339"/>
        <source>Cursors</source>
        <extracomment>cursor theme</extracomment>
        <translation>Kazalci</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="346"/>
        <source>Save Current Settings as a Theme Set</source>
        <extracomment>save theme settings as a group</extracomment>
        <translation>Shrani trenutne nastavitve kot tematski set</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="356"/>
        <source>Size</source>
        <extracomment>size of the cursor</extracomment>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="366"/>
        <source>default</source>
        <extracomment>default cursor size determined by X server</extracomment>
        <translation>privzeto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="389"/>
        <location filename="../tweak.ui" line="441"/>
        <source>Compositor</source>
        <translation>Sestavljalnik</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="401"/>
        <source>Changing the VBlank mode may help alleviate some screen tearing issues. See Help for more information.</source>
        <translation>Spreminjanje VBlank načina lahko odpravi težave s prelivanjem sličic na zaslonu. Glej pomoč za več podatkov.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="404"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="412"/>
        <source>auto</source>
        <translation>samodejno</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="417"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="422"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="427"/>
        <location filename="../tweak.ui" line="1010"/>
        <source>off</source>
        <extracomment>setting to 0 turns off screensaver screen blank</extracomment>
        <translation>izklopljeno</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="435"/>
        <source>Transparency and shadow options</source>
        <translation>Opcije za prosojnost in sence</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="451"/>
        <source>Xfce Compositor Settings</source>
        <translation>Nastavitve za Xfwm kompozitor</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="454"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm nastavitve</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="464"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Zaženi compton-conf konfiguracijsko orodje</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="467"/>
        <source>Picom settings</source>
        <translation>Picom nastavitve</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="478"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Uredi compton.conf neposredno v urejvalniku teksta</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="481"/>
        <source>Edit picom.conf</source>
        <translation>Uredi picom.conf</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="528"/>
        <source>Display</source>
        <translation>Zaslon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="534"/>
        <source>Display Tweaks</source>
        <translation>Prikaži prilagoditve</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="540"/>
        <source>Hardware Backlight</source>
        <extracomment>set the hardware backlight on monitors that have them</extracomment>
        <translation>Strojna zadnja osvetlitev</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="563"/>
        <location filename="../tweak.ui" line="694"/>
        <source>TextLabel</source>
        <translation>TekstovnaOznaka</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="570"/>
        <source>GTK scaling</source>
        <extracomment>gtk scale factor</extracomment>
        <translation>GTK prilagajanje velikosti</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="623"/>
        <source>Choose Display for xrandr tweaks</source>
        <extracomment>choose the display that the xrandr tweaks will be acted upon</extracomment>
        <translation>Izberite prikaz za xrandr prilagoditve</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="633"/>
        <source>Resolution</source>
        <translation>Ločljivost</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="650"/>
        <source>xrandr Scaling</source>
        <extracomment>xrandr scale factor</extracomment>
        <translation>xrandr prilagajanje velikosti</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="677"/>
        <source>Software (xrandr) Brightness</source>
        <extracomment>adjust brightness (not backlight) via software</extracomment>
        <translation>Programska (xrandr) osvetlitev</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="701"/>
        <source>Saving is per display</source>
        <translation>Shranjuje se za en zaslon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="704"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="728"/>
        <source>Xfce</source>
        <translation>Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="734"/>
        <source>Desktop</source>
        <translation>Namizje</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="740"/>
        <source>Enable single-click on desktop</source>
        <translation>Vklopi enojni klik na namizju</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="747"/>
        <source>Enable Desktop Zoom </source>
        <translation>Vklopi povečavo namizja</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="754"/>
        <location filename="../tweak.ui" line="1343"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>V panoju prikaži okna z vseh delovnih površin</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="761"/>
        <source>Do not shorten file names on the desktop</source>
        <translation>Ne okrajšaj imen datotek na namizju</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="771"/>
        <source>Thunar</source>
        <translation>Thunar</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="777"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Vklopi enojni klik v Thunar upravljalniku datotek</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="784"/>
        <source>Reset custom right-click actions to system defaults</source>
        <translation>Ponastavi dejanja za desni klik po meri na sistemsko privzete</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="791"/>
        <source>Thunar windows always open in split view</source>
        <translation>Thunar okno se vedno odpre v razdeljenem prikazu</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="798"/>
        <source>Thunar split view opens horizontal</source>
        <translation>Thunar se odpre z vodoravnim razdeljenim prikazom</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="808"/>
        <source>Show percentages in notifcations when available</source>
        <translation>V obvestilih uporabi odstotke, kadar so na voljo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="815"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>Na dnu dialogov prikaži GTK File Dialog akcijske gumbe</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="822"/>
        <source>(also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(za Xfce programe izklopi tudi  okrasitve s strani odjemalca)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="832"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>V odjavnem meniju omogoči hibernacijo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="839"/>
        <source>note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>opomba: za spanje mora biti swap &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="873"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="879"/>
        <location filename="../tweak.ui" line="1353"/>
        <source>Reset Defaults</source>
        <translation>Ponastavi na privzeto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="885"/>
        <source>Reset DefaultDock</source>
        <translation>Ponastavi PrivzetoSidrišče</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="892"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Ponastavi Fluxbox meni</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="899"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Ponastavi VSE nastavitve mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="906"/>
        <source>Add new default menu items, if any, to existing fluxbox menu.</source>
        <translation>Dodaj nove privzete predmete menija, če obstajajo, v obstoječi fluxbox meni.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="909"/>
        <source>Upgrade existing menu entries</source>
        <translation>Nadgradi obstoječe vnose menija</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="919"/>
        <source>Desktop Icons</source>
        <translation>Ikone namizja</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="925"/>
        <source>Toggle desktop icons</source>
        <translation>Preklopi prikaz namiznih ikon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="933"/>
        <location filename="../tweak.ui" line="957"/>
        <source>On</source>
        <translation>Vklop</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="938"/>
        <location filename="../tweak.ui" line="962"/>
        <source>Off</source>
        <translation>Izklop</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="946"/>
        <source>Toggle icon captions</source>
        <translation>Preklopi prikaz oznak ikon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="967"/>
        <source>On Hover</source>
        <translation>Ob prehodu</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="994"/>
        <source>Screensaver</source>
        <translation>Ohranjevalnik zaslona</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1000"/>
        <source>Idle time (minutes)</source>
        <extracomment>set the time of inactivity  before screensaver screen blank occurs</extracomment>
        <translation>Čas nedejavnosti (v minutah)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1023"/>
        <source>Toolbar Settings</source>
        <translation>Nastavitve orodne vrstice</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1029"/>
        <source>Height</source>
        <translation>Višina</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1110"/>
        <location filename="../tweak.ui" line="1220"/>
        <source>Autohide</source>
        <translation>Samodejno skrij</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1117"/>
        <source>Show Toolbar</source>
        <translation>Prikaži orodno vrstico</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1124"/>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1140"/>
        <source>Dock Settings</source>
        <translation>Nastavitve sidrišča</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1227"/>
        <source>Manage Tint2 Panel</source>
        <translation>Upravljaj Tint2 pano</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1261"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1267"/>
        <source>Affects 1st panel</source>
        <translation>Vpliva na prvi pano</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1284"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1289"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1294"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1299"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1323"/>
        <source>Workspace</source>
        <translation>Delovna površina</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1329"/>
        <source>Autostart plasma-discover system tray update notification utility</source>
        <extracomment>enable or disable autostartup of plasma-discover updater utility on login</extracomment>
        <translation>Samodejni zagon obvestilnika za posodobitve plasma-discover v sistemski pasici</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1336"/>
        <source>Enable single-click</source>
        <translation>Vklopi en klik</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1359"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Ponastavi KDE/Plasma na privzeto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1393"/>
        <source>Super Key</source>
        <extracomment>referring to the meta or Left Super Key</extracomment>
        <translation>Super tipka</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1399"/>
        <source>Also known as the &quot;windows&quot; key</source>
        <translation>Znana tudi kot tipka &quot;windows&quot;</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1402"/>
        <source>Command to run with Super (Meta) key</source>
        <extracomment>label for the field to enter the command to use with super key</extracomment>
        <translation>Ukaz, ki naj se zažene preko Super (Meta) tipke</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1412"/>
        <source>xfce-superkey defaults</source>
        <extracomment>indicates that xfce-superkey will select a command by its default logic</extracomment>
        <translation>xfce-superkey privzeto</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1419"/>
        <source>Choose application</source>
        <extracomment>description of button action to launch file dialog to choose an application</extracomment>
        <translation>Izberite program</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1450"/>
        <source>Miscellaneous</source>
        <translation>Razno</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1456"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Ponastavi Lightdm (zaslon za prijavo) na privzeto temo sistema</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1463"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Omogoči priklop notranjih pogonov ne-korenskim uporabnikom</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1470"/>
        <source>Enable kernel sandbox</source>
        <translation>Vklopi peskovnik za jedro</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1477"/>
        <source>requires reboot</source>
        <translation>zahteva ponovni zagon</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1480"/>
        <source>Enable Bluetooth adapters on boot</source>
        <translation>Ob zagonu vklopi Bluetooth vmesnike</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1487"/>
        <source>Enable Bluetooth battery info for connected devices (requires system restart)</source>
        <extracomment>expose battery info for connected bluetooth devices to the operating system via dbus</extracomment>
        <translation>Vklopi Bluetooth podatke o bateriji za povezane naprave (zahteva ponovni zagon)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1494"/>
        <source>Early loading of KVM module is new to  kernel 6.12 and conflicts with some non-KVM virtual machine applications, including virtualbox</source>
        <extracomment>early loading is new on 6.12 kernel and conflicts with virtualbox</extracomment>
        <translation>Zgodnje nalaganje KVM modula je novost v jedru 6.12 in ne deluje z nekaterimi ne-KVM programi za virtualizacijo, vključno s programom Virtualbox. </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1497"/>
        <source>Disable early KVM module load (must be disabled for Virtualbox operation on kernel 6.12 and up)</source>
        <extracomment>disable early loading of KVM module.  necessary for virtualbox to function with kernels 6.12 and up.  actually default behavior on kernels 6.11 and earlier.</extracomment>
        <translation>Onemogoči zgodnje nalaganje KVM modula (mora biti onemogočen za delovanje Virtualbox-a od jedra 6.12 naprej)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1504"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Apt namesti dodatne &quot;priporočene&quot; pakete kot odvisnosti</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1511"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>Generiranje menija za vse fluxbox aplikacije, po nameščanju, odstranjevanju ali posodabljanju.</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1518"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Uporabi okraske Client Side Decorations (CSD) v aplikacijah GTK3, ki jih podpirajo (zahteva ponoven zagon seje) </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1525"/>
        <source>put a hold or remove a hold on updates of Liquorix kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>Opusti ali ponovno vzpostavi posadabljanje Liquorix jeder</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1528"/>
        <source>Enable Automatic Liquorix Kernel Updates (MX ahs repository)</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Vklopi samodejno posodabljanje jeder (MX ahs skladišče)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1535"/>
        <source>put a hold or remove a hold on updates of Debian  kernels</source>
        <extracomment>toggle for apt hold action on update meta packages</extracomment>
        <translation>Opusti ali ponovno vzpostavi posodabljanje Debian jeder</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1538"/>
        <source>Enable Automatic Debian Kernel Updates</source>
        <extracomment>uses apt-mark to hold or unhold updates to kernel metapackages</extracomment>
        <translation>Vklopi samodejno posodabljanje Debian jeder</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1545"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Namesto privzetega &quot;modesetting&quot; gonilnika uporabite Intel gonilnik (zahteva ponovni zagon)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1571"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-intel.conf bo varnostno kopiran v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1578"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Uporabi amdgpu opcijo za odpravljanje napak v prikazovanju </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1585"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-amd.conf bo varnostno shranjen v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1592"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Uporabi radeon opcijo za odpravljanje napak v prikazovanju </translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1599"/>
        <source>NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>POMNI: obstoječi /etc/X11/xorg.conf.d/20-radeon.conf bo varnostno kopiran v domačo home mapo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1606"/>
        <source>Change computer name (requires reboot)</source>
        <extracomment>option to change the system hostname, requires a reboot to be 100% effective</extracomment>
        <translation>Spremeni ime računalnika (zahteva ponovni zagon)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1616"/>
        <source>Change Default Display Manager (login screen) (requires reboot)</source>
        <extracomment>option to change display manager login screen.  present if more than one display manager is installed</extracomment>
        <translation>Spremeni privzeti upravljalnik zaslona (ob prijavi) (zahteva ponovni zagon)</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1629"/>
        <source>Password for administrative tasks:</source>
        <translation>Geslo za adminstracijo:</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1636"/>
        <source>&amp;User</source>
        <translation>&amp;Uporabnik</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1643"/>
        <source>Root</source>
        <translation>Koren</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1693"/>
        <source>Xfce Settings</source>
        <translation>Xfce nastavitve</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1699"/>
        <source>Customize the panel</source>
        <translation>Prilagodi pano</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1709"/>
        <source>Panel</source>
        <translation>Pano</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1729"/>
        <source>Configure window behavior and shortcuts</source>
        <translation>Nastavi obnašanje oken in bližnjice</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1762"/>
        <source>Customize the look of your desktop</source>
        <translation>Prilagodi videz namizja</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1775"/>
        <source>Appearance</source>
        <translation>Videz</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1787"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1797"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1855"/>
        <source>Quit application</source>
        <translation>Zapri aplikacijo</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1858"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../tweak.ui" line="1864"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="72"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display stikalo ve veljavno le za Xfce</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="241"/>
        <source>About MX Tweak</source>
        <translation>O programu MX prilagoditve</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="243"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="244"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Aplikacija za hitro spreminjanje in prilagajanje privzete teme uporabniškega vmesnika</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="246"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Avtorska zaščita (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="247"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="../tweak.cpp" line="261"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
</context>
<context>
    <name>TweakCompositor</name>
    <message>
        <location filename="../tweak_compositor.cpp" line="62"/>
        <source>None</source>
        <translation>brez</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="63"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) sestavljalnik</translation>
    </message>
    <message>
        <location filename="../tweak_compositor.cpp" line="64"/>
        <source>Picom</source>
        <translation>Picom</translation>
    </message>
</context>
<context>
    <name>TweakMisc</name>
    <message>
        <location filename="../tweak_misc.cpp" line="289"/>
        <source>Please enter a computer name.</source>
        <comment>question to enter a name for the computer hostname</comment>
        <translation>Vnesite ime računalnika.</translation>
    </message>
    <message>
        <location filename="../tweak_misc.cpp" line="293"/>
        <source>Sorry, your computer name contains invalid characters.
You'll have to select a different
name before proceeding.</source>
        <comment>unacceptable characters are found in hostname, pick a new name</comment>
        <translation>Oprostite, ime vašega računalnika vsebuje nedovoljene znake.
Morali boste izbrati
drugo ime, preden lahko nadaljujete.</translation>
    </message>
</context>
<context>
    <name>TweakSuperKey</name>
    <message>
        <location filename="../tweak_superkey.cpp" line="43"/>
        <source>Select application to run</source>
        <comment>will show in file dialog when selection an application to run</comment>
        <translation>Izbira programa za zagon</translation>
    </message>
</context>
<context>
    <name>TweakTheme</name>
    <message>
        <location filename="../tweak_theme.cpp" line="64"/>
        <source>Plasma Widget Themes</source>
        <comment>theme style of the kde plasma widgets</comment>
        <translation>Teme za plazma gradnike</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="65"/>
        <source>Color Schemes</source>
        <comment>plasma widget color schemes</comment>
        <translation>Barvne sheme</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="66"/>
        <source>Plasma Look &amp; Feel Global Themes</source>
        <comment>plasma global themes</comment>
        <translation>Plasma teme za videz in občutek</translation>
    </message>
    <message>
        <location filename="../tweak_theme.cpp" line="139"/>
        <source>Choose a theme set</source>
        <translation>Izberite tematski set</translation>
    </message>
</context>
<context>
    <name>TweakXfcePanel</name>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="17"/>
        <source>Horizontal (Bottom)</source>
        <translation>Vodoravno (spodaj)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="18"/>
        <source>Horizontal (Top)</source>
        <translation>Vodoravno (zgoraj)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="20"/>
        <source>Vertical (Left)</source>
        <translation>Navpično (levo)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="21"/>
        <source>Vertical (Right)</source>
        <translation>Navpično (desno)</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="23"/>
        <source>docklike</source>
        <translation>docklike</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Gumbi oken</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="273"/>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <location filename="../tweak_xfce_panel.cpp" line="297"/>
        <location filename="../tweak_xfce_panel.cpp" line="301"/>
        <source>MX Tweak</source>
        <translation>MX prilagoditve</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>Plese remove special characters</source>
        <translation>Odstranite posebne znake</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="274"/>
        <source>from file name</source>
        <translation>iz imena datoteke</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="280"/>
        <source>File name already exists.  Choose another name</source>
        <translation>Ime datoteke že obstaja. Izberite drugo ime</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="298"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>Datoteka ni ustrezna tar.xz arhivska datoteka</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="302"/>
        <source>Archive does not contain a panel config</source>
        <translation>Arhiv ne vsebuje konfiguracije panojev</translation>
    </message>
    <message>
        <location filename="../tweak_xfce_panel.cpp" line="733"/>
        <source>Panel Preferences</source>
        <translation>Nastavitve panoja</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Glavno okno</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="34"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="41"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Programska (xrandr) osvetlitev</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="61"/>
        <location filename="../brightness_small.ui" line="89"/>
        <source>TextLabel</source>
        <translation>TekstovnaOznaka</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="68"/>
        <source>Save</source>
        <translation>Shrani</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="75"/>
        <source>Hardware Backlight</source>
        <translation>Strojna zadnja osvetlitev</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="35"/>
        <source>Brightness</source>
        <translation>Osvetljenost</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="54"/>
        <source>Display</source>
        <translation>Zaslon</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="59"/>
        <source>&amp;Quit</source>
        <translation>&amp;Končaj</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Odstranite uporabnikov tematski set</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Nov tematski set</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Vnesite ime za nov tematski set</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="38"/>
        <source>Window Buttons</source>
        <translation>Gumbi oken</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="23"/>
        <source>Appearance</source>
        <translation>Videz</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="29"/>
        <source>Show button labels</source>
        <translation>Prikaži oznake za gumbe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="36"/>
        <source>Show flat buttons</source>
        <translation>Prikaži ravne gumbe</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="43"/>
        <source>Show handle</source>
        <translation>Prikaži ročico</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="50"/>
        <source>Sorting Order:</source>
        <translation>Vrstni red sortiranja:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="58"/>
        <source>Timestamp</source>
        <translation>Časovna oznaka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="63"/>
        <source>Group title and timestamp</source>
        <translation>Naziv skupine in časovna oznaka</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="68"/>
        <source>Window Title</source>
        <translation>Naziv okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="73"/>
        <source>Group title and window title</source>
        <translation>Naziv skupine in okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="78"/>
        <source>None, allow drag-and-drop</source>
        <translation>Brez, dovoli vlecenje in spuščanje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="89"/>
        <source>Behavior</source>
        <translation>Obnašanje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="95"/>
        <source>Window grouping:</source>
        <translation>Zbiranje oken v skupino:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="103"/>
        <source>Never</source>
        <translation>Nikoli</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="108"/>
        <source>Always</source>
        <translation>Vedno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="116"/>
        <source>Middle click action:</source>
        <translation>Dejanje ob kliku na srednjo tipko:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="124"/>
        <source>Nothing</source>
        <translation>Ničesar</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="129"/>
        <source>Close window</source>
        <translation>Zapri okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="134"/>
        <source>Minimize window</source>
        <translation>Zmanjšaj okno</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="142"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Obnovi zmanjšano okno na trenutno delovno površino</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="149"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Nariši okvir okna, ko lebdiš nad gumbom </translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="156"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Preklapljanje med okni z uporabo kolesca miške</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="166"/>
        <source>Filtering</source>
        <translation>Filtriranje</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="172"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Prikaži okna z vseh delovnih površin in pogledov</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="179"/>
        <source>Show only minimized windows</source>
        <translation>Prikaži le zmanjšana okna</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="186"/>
        <source>Show windows from all monitors</source>
        <translation>Prikaži okna z vseh monitorjev</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="210"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="23"/>
        <source>Feature Settings</source>
        <translation>Funkcionalne nastavitve</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="29"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Neposredno prekrij cel zaslon z oknom </translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="36"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Sinhorniziraj izrisovanje z vertikalnim signalom</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="43"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Prikaži predogled okna namesto ikon, kadar krožiš</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="50"/>
        <source>Show shadows under popup windows</source>
        <translation>Prikaži sence pod pojavnimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="57"/>
        <source>Show shadows under dock windows</source>
        <translation>Prikaži sence pod zasidranimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="64"/>
        <source>Show shadows under regular windows</source>
        <translation>Prikaži sence pod običajnimi okni</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="74"/>
        <source>Opacity Settings</source>
        <translation>Nastavitve prekrivnosti</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="80"/>
        <source>Window decorations</source>
        <translation>Okraski za okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="103"/>
        <source>Inactive windows</source>
        <translation>Neaktivna okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="126"/>
        <source>Windows during move</source>
        <translation>Okna med premikanjem</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="149"/>
        <source>Windows during resize</source>
        <translation>Okna med spreminjanjem velikosti</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="172"/>
        <source>Popup Windows</source>
        <translation>Pojavna okna</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="205"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="25"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Nastavitve za Xfwm kompozitor</translation>
    </message>
</context>
</TS>